#
# spec file for package python-virtualenv-clone
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-virtualenv-clone
Version:        0.2.6
Release:        lp150.1.3
Summary:        Script to clone virtualenvs
License:        MIT
Group:          Development/Languages/Python
Url:            http://github.com/edwardgeorge/virtualenv-clone
Source:         https://files.pythonhosted.org/packages/source/v/virtualenv-clone/virtualenv-clone-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
Recommends:     python-virtualenv
Requires(post):   update-alternatives
Requires(preun):  update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
virtualenv cloning script.

A script for cloning a non-relocatable virtualenv.

Virtualenv provides a way to make virtualenv's relocatable which could then be
copied as we wanted. However making a virtualenv relocatable this way breaks
the no-site-packages isolation of the virtualenv as well as other aspects that
come with relative paths and '/usr/bin/env' shebangs that may be undesirable.

Also, the .pth and .egg-link rewriting doesn't seem to work as intended. This
attempts to overcome these issues and provide a way to easily clone an
existing virtualenv.

It performs the following:

- copies sys.argv[1] dir to sys.argv[2]
- updates the hardcoded VIRTUAL_ENV variable in the activate script to the
  new repo location. (--relocatable doesn't touch this)
- updates the shebangs of the various scripts in bin to the new python if
  they pointed to the old python. (version numbering is retained.)

    it can also change '/usr/bin/env python' shebangs to be absolute too,
    though this functionality is not exposed at present.

- checks sys.path of the cloned virtualenv and if any of the paths are from
  the old environment it finds any .pth or .egg-link files within sys.path
  located in the new environment and makes sure any absolute paths to the
  old environment are updated to the new environment.

- finally it double checks sys.path again and will fail if there are still
  paths from the old environment present.

%prep
%setup -q -n virtualenv-clone-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# setup up update-alternatives
%python_clone -a %{buildroot}%{_bindir}/virtualenv-clone

%post
%python_install_alternative virtualenv-clone

%preun
%python_uninstall_alternative virtualenv-clone

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README
%python_alternative %{_bindir}/virtualenv-clone
%{python_sitelib}/*

%changelog
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Mon Feb 29 2016 someuniquename@gmail.com
- Update to version 2.6
  * Fix symlinks that point to the old virtual env
* Tue Dec  9 2014 toddrme2178@gmail.com
- Fix update-alternatives as requested.
* Mon Dec  1 2014 toddrme2178@gmail.com
- Update to 2.5
  * Speed clone_virtualenv up slightly by removing duplicate calls
    to spawn process
  * Improve windows compatibility
  * Ship LICENSE along with the source distribution to pypi.
  * Added verbose mode with logging.
  * Bugfixes
- Implement update alternatives to allow co-install with python 3
  version.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Aug  2 2012 alexandre@exatati.com.br
- Initial package (0.2.4) for openSUSE.
